external Package
================

:mod:`external` Package
-----------------------

.. automodule:: numba.external
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`external` Module
----------------------

.. automodule:: numba.external.external
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`libc` Module
------------------

.. automodule:: numba.external.libc
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`pyapi` Module
-------------------

.. automodule:: numba.external.pyapi
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`utility` Module
---------------------

.. automodule:: numba.external.utility
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    numba.external.utilities

